.. _api-label:

=============
API Reference
=============

pyadrc.pyadrc
-------------

.. automodule:: pyadrc.pyadrc
   :members:
   :special-members:
   :exclude-members: __dict__, __weakref__, __init__, __module__
   :undoc-members:
   

pyadrc.models
--------------

.. automodule:: pyadrc.models
   :members:
   :special-members:
   :exclude-members: __dict__, __weakref__, __init__, __module__
   :undoc-members: